==> searduino-0.8.tar.gz: searduino-0.8/simulators/jearduino/com/sandklef/jearduino/JearduinoEvent.java <==
/*****
 *                                                                   
 *                   Searduino
 *                      
 *   Copyright (C) 2013 Henrik Sandklef 
 *                                                                   
 * This program is free software; you can redistribute it and/or     
 * modify it under the terms of the GNU General Public License       
 * as published by the Free Software Foundation; either version 3    
 * of the License, or any later version.                             
 *                                                                   
 *                                                                   
 * This program is distributed in the hope that it will be useful,   
 * but WITHOUT ANY WARRANTY; without even the implied warranty of    
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     
 * GNU General Public License for more details.                      
 *                                                                   
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software       
 * Foundation, Inc., 51 Franklin Street, Boston,            
 * MA  02110-1301, USA.                                              
 ****/

package com.sandklef.jearduino;

import java.io.File;




public interface JearduinoEvent
{
    public static int JEARDUINO_EVENT_BUILD_PROJECT = 1;

    public void handleJearduinoEvent(int i, Object o);
}

==> searduino-0.9.94.tar.gz: searduino-0.9.94/simulators/jearduino/com/sandklef/jearduino/JearduinoEvent.java <==
/*****
 *                                                                   
 *                   Searduino
 *                      
 *   Copyright (C) 2013 Henrik Sandklef 
 *                                                                   
 * This program is free software; you can redistribute it and/or     
 * modify it under the terms of the GNU General Public License       
 * as published by the Free Software Foundation; either version 3    
 * of the License, or any later version.                             
 *                                                                   
 *                                                                   
 * This program is distributed in the hope that it will be useful,   
 * but WITHOUT ANY WARRANTY; without even the implied warranty of    
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     
 * GNU General Public License for more details.                      
 *                                                                   
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software       
 * Foundation, Inc., 51 Franklin Street, Boston,            
 * MA  02110-1301, USA.                                              
 ****/

package com.sandklef.jearduino;

import java.io.File;




public interface JearduinoEvent
{
    public static int JEARDUINO_EVENT_BUILD_PROJECT = 1;
    public static int JEARDUINO_EVENT_BUILD_ARDUINO = 2;
    public static int JEARDUINO_EVENT_UPLOAD        = 3;

    public void handleJearduinoEvent(int i, Object o);
}
